==> openjdk-22_22~12ea.orig.tar.xz: openjdk-22-22~12ea/test/langtools/tools/javac/constDebug/ConstDebugTest.java <==
/*
 * Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4645152 4785453
 * @summary javac compiler incorrectly inserts <clinit> when -g is specified
 * @modules java.base/jdk.internal.classfile
 *          java.base/jdk.internal.classfile.attribute
 *          java.base/jdk.internal.classfile.constantpool
 *          java.base/jdk.internal.classfile.instruction
 *          java.base/jdk.internal.classfile.components
 * @run compile -g ConstDebugTest.java
 * @run main ConstDebugTest
 */
import java.nio.file.Paths;
import jdk.internal.classfile.*;

public class ConstDebugTest {

    public static final long l = 12;

    public static void main(String args[]) throws Exception {
        ClassModel classModel = Classfile.of().parse(Paths.get(System.getProperty("test.classes"),
                ConstDebugTest.class.getSimpleName() + ".class"));
        for (MethodModel method: classModel.methods()) {
            if (method.methodName().equalsString("<clinit>")) {
                throw new AssertionError(
                    "javac should not create a <clinit> method for ConstDebugTest class");
            }
        }
    }

}

==> openjdk-24_24~29ea.orig.tar.xz: openjdk-24-24~29ea/test/langtools/tools/javac/constDebug/ConstDebugTest.java <==
/*
 * Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 4645152 4785453
 * @summary javac compiler incorrectly inserts <clinit> when -g is specified
 * @run compile -g ConstDebugTest.java
 * @run main ConstDebugTest
 */
import java.nio.file.Paths;
import java.lang.classfile.*;

public class ConstDebugTest {

    public static final long l = 12;

    public static void main(String args[]) throws Exception {
        ClassModel classModel = ClassFile.of().parse(Paths.get(System.getProperty("test.classes"),
                ConstDebugTest.class.getSimpleName() + ".class"));
        for (MethodModel method: classModel.methods()) {
            if (method.methodName().equalsString("<clinit>")) {
                throw new AssertionError(
                    "javac should not create a <clinit> method for ConstDebugTest class");
            }
        }
    }

}
